/* eslint-disable @next/next/no-img-element */
"use client";
import React, { useEffect, useState } from "react";
import Css from "@/components/CssEntrepise";
import Header from "@/components/HeaderEntreprise";
import Footer from "@/components/FooterEntrepise";
import Myscript from "@/components/ScriptEntreprise";
import Sidebar from "@/components/SidbarEntreprise";
import { useRouter } from "next/navigation";
import apiService from "../services/apiService";
interface Application {
  user:{
    name:string;
    profile: {
      profile_picture_path: string;
      title:string;
      address:string;
    };
  };
  id: number;
  user_id: number;
  job_listing_id: number;
  cover_letter: string;
  resume_path: string;
  status: string;
  created_at: string;
}
interface JobsListing {
  application: string;
  id: number;
  user_id:number;
    title: string,
    description: string,
    category_id: number,
    location: string,
    experience_level: string,
    contract_type: string,
    min_salary: number,
    max_salary: number,
    created_at:string
};
export default function Home() { 
  const router = useRouter();
  const [applicationList, setApplicationList] = useState<Application[]>([]);
  const [applicationAppliedList, setApplicationAppliedList] = useState<Application[]>([]);
  const [applicationRemoveList, setApplicationRemoveList] = useState<Application[]>([]);
  const [jobsListing, setJobListing] = useState<JobsListing[]>([]);

  const handleShow = async (show: number) => {
    router.push(`/dashboardEntreprise/candidat/show/${show}`);
  };

  const formatDate = (dateString: string | number | Date) => {
    const options: Intl.DateTimeFormatOptions = { 
      year: "numeric", 
      month: "long", 
      day: "numeric" 
    };    const date = new Date(dateString);
    return date.toLocaleDateString("fr-FR", options);
  };
  const laodsApplication = async () => {
    try {
      const applicationData = await apiService.getAllResources("applications");
      const JobData = await apiService.getAllResources("job_listings");

      const filteredapplicationDataApplied = applicationData.filter(
        (application: { status: string }) => application.status === "accepted"
      );
      const filteredapplicationDataRemoved = applicationData.filter(
        (application: { status: string }) => application.status === "rejected"
      );
      console.log(JobData);
      setJobListing(JobData);
      setApplicationList(applicationData);
      setApplicationAppliedList(filteredapplicationDataApplied);
      setApplicationRemoveList(filteredapplicationDataRemoved);
      } catch (error) {
      console.error(error);
    }
  };
  function handleDownload(fileUrl:string) {
    const link = document.createElement("a");
    link.href = fileUrl;
    link.setAttribute("download", "CV.pdf");
    document.body.appendChild(link);
    link.click();
    link.remove();
  }
  useEffect(() => {
    laodsApplication();
  }, []);
  return (
    <>
  <Css/>
  <Header/>
  {/* xxx */}
  <div className="template-dashboard">

  <div className="dashboard__content d-flex">
  <Sidebar/>
  <div className="dashboard__right">
    <div className="dash__content">
      {/* sidebar menu */}
      <div className="sidebar__menu d-md-block d-lg-none">
        <div className="sidebar__action">
          <i className="fa-sharp fa-regular fa-bars" /> Sidebar
        </div>
      </div>
      {/* sidebar menu end */}
      <div className="dash__overview">
        <h6 className="fw-medium mb-30">Applications Overview</h6>
        <div className="overview__content">
          <div className="single__overview">
            <div className="icon">
              <svg
                width={30}
                height={30}
                viewBox="0 0 30 30"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
              >
                <path
                  fillRule="evenodd"
                  clipRule="evenodd"
                  d="M29.08 29.0907H22.3254V27.6087H29.08V29.0907ZM24.2082 26.0839C24.2043 26.0372 24.1965 25.9912 24.1771 25.9476C23.4473 24.1535 23.2959 22.0737 23.7152 19.5894C23.7462 19.4093 23.6647 19.2286 23.5094 19.1309L20.6328 17.3299C20.1015 16.9966 20.2512 16.2014 20.8541 16.0686C21.0405 16.028 21.2268 16.0602 21.386 16.1586L24.8487 18.328C25.1563 18.5191 25.5591 18.2996 25.5591 17.9434V11.0411C26.9644 12.8049 27.3449 16.0629 27.6865 18.9842C27.8573 20.4213 28.0165 21.7791 28.2843 22.9377C28.3387 23.202 28.393 25.2938 28.2765 26.6998H24.2548L24.2082 26.0839ZM7.16622 24.7069H22.8301C22.5001 23.2232 22.4768 21.5819 22.7602 19.7384L20.1398 18.0975C19.3829 17.6245 19.1577 16.6317 19.6391 15.8856C20.1159 15.1412 21.1233 14.9177 21.879 15.391L24.6352 17.117V4.78475H22.5545C21.5374 4.78475 20.7067 3.96738 20.7067 2.96267V0.907779H6.28889C5.77647 0.907779 5.36106 1.31759 5.36106 1.82093V17.117L8.12119 15.3911C8.48611 15.1625 8.92089 15.0882 9.34402 15.182C10.7602 15.4947 11.0715 17.3381 9.86036 18.0975L7.24 19.7384C7.52335 21.5819 7.50007 23.2232 7.16622 24.7069ZM1.72366 26.6998C1.60331 25.2938 1.65766 23.2021 1.71588 22.9377C1.98373 21.7791 2.14287 20.4213 2.30986 18.9842C2.65149 16.0628 3.03577 12.8048 4.44108 11.0411V17.9435C4.44108 18.298 4.84286 18.5199 5.14763 18.3281L8.61425 16.1587C9.12377 15.8377 9.8131 16.2746 9.67401 16.8952C9.63515 17.0772 9.52258 17.2311 9.3673 17.33L6.49074 19.131C6.33546 19.2287 6.25396 19.4095 6.28111 19.5895C6.70424 22.0737 6.55281 24.1536 5.82305 25.9477C5.80362 25.9914 5.79198 26.0373 5.78812 26.084L5.74541 26.6999L1.72366 26.6998ZM7.67085 29.0907H0.920113V27.6087H7.67092L7.67085 29.0907ZM21.6267 1.55128L23.983 3.87548H22.5544C22.042 3.87548 21.6266 3.46642 21.6266 2.96274L21.6267 1.55128ZM29.2004 26.7064C29.3129 25.2566 29.2702 23.119 29.181 22.7367C28.278 18.846 28.617 12.2156 25.5591 9.74487V4.33008C25.5591 4.20984 25.5086 4.09415 25.4232 4.00871L21.4946 0.134043C21.4053 0.0459497 21.2888 0 21.1685 0H6.28889C5.27178 0 4.44108 0.815811 4.44108 1.82093V9.74494C1.38596 12.2132 1.71471 18.8488 0.819119 22.7367C0.729835 23.119 0.687123 25.2566 0.799691 26.7064C0.349417 26.7584 0 27.1373 0 27.5961V29.1034C0 29.5975 0.40763 30 0.908402 30H7.68635C8.18712 30 8.59475 29.5975 8.59475 29.1034V27.5961C8.59475 27.1016 8.18712 26.6998 7.68635 26.6998H6.66924L6.70417 26.2203C6.78181 26.0223 6.85166 25.8204 6.92159 25.6163H23.0785C23.1445 25.8204 23.2183 26.0223 23.2958 26.2203L23.3308 26.6998H22.3136C21.8129 26.6998 21.4052 27.1016 21.4052 27.5961V29.1034C21.4052 29.5975 21.8129 30 22.3136 30H29.0916C29.5924 30 30 29.5975 30 29.1034V27.5961C30.0001 27.1373 29.6507 26.7584 29.2004 26.7064ZM18.1266 12.0242L18.8952 12.8664C19.0653 13.0552 19.3545 13.0679 19.5435 12.9024L21.4573 11.2175C21.6475 11.0501 21.6669 10.7629 21.4961 10.5756C21.3253 10.3883 21.0342 10.3714 20.8439 10.5388L19.2717 11.9223L18.8136 11.4171C18.6429 11.2302 18.3517 11.2145 18.1615 11.3822C17.9752 11.5504 17.9558 11.8377 18.1266 12.0242ZM20.1049 20.7725C20.1049 20.5216 19.8991 20.3178 19.6429 20.3178H10.3533C10.101 20.3178 9.89528 20.5216 9.89528 20.7725C9.89528 21.0234 10.1011 21.2268 10.3533 21.2268H19.6429C19.8991 21.2268 20.1049 21.0234 20.1049 20.7725ZM18.1266 6.70952C17.9558 6.52218 17.9752 6.23493 18.1615 6.06683C18.3517 5.89982 18.6429 5.91478 18.8137 6.10204L19.2718 6.60762L20.8439 5.22376C21.0342 5.05675 21.3254 5.07286 21.4961 5.26013C21.667 5.44739 21.6476 5.73546 21.4574 5.90207L19.5436 7.58773C19.3544 7.75209 19.0655 7.74033 18.8953 7.5517L18.1266 6.70952ZM14.7167 13.6085H8.83153V10.6339C8.83153 9.0332 10.1514 7.73057 11.7741 7.73057C13.3968 7.73057 14.7167 9.0332 14.7167 10.6339V13.6085ZM10.2912 5.35736C10.2912 4.54991 10.955 3.89308 11.7742 3.89308C12.5933 3.89308 13.257 4.54997 13.257 5.35736C13.257 6.1644 12.5932 6.82088 11.7742 6.82163C10.955 6.82088 10.2912 6.1644 10.2912 5.35736ZM15.6367 14.0631C15.6367 14.3144 15.431 14.5178 15.1786 14.5178H8.36962C8.11727 14.5178 7.91156 14.3144 7.91156 14.0631V10.6339C7.91156 9.08343 8.85096 7.74783 10.2019 7.15184C9.69336 6.71675 9.3673 6.07366 9.3673 5.35736C9.3673 4.04895 10.4465 2.98374 11.7742 2.98374C13.1018 2.98374 14.181 4.04895 14.181 5.35736C14.181 6.07359 13.855 6.71668 13.3464 7.15259C14.6934 7.74783 15.6368 9.08343 15.6368 10.6339L15.6367 14.0631Z"
                  fill="#34A853"
                />
              </svg>
            </div>
            <div className="content">
              <h5 className="lh-sm">{jobsListing.length}</h5>
              <p className="font-20">Job Posted</p>
            </div>
          </div>
          <div className="single__overview">
            <div className="icon">
              <svg
                width={30}
                height={30}
                viewBox="0 0 30 30"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
              >
                <g clipPath="url(#application)">
                  <path
                    d="M24.2586 8.71582C24.5821 8.71582 24.8445 8.4535 24.8445 8.12988V1.75781C24.8445 0.788555 24.056 0 23.0867 0H1.75857C0.78931 0 0.00075531 0.788555 0.00075531 1.75781V28.2422C0.00075531 29.2114 0.78931 30 1.75857 30H23.0867C24.056 30 24.8445 29.2114 24.8445 28.2422V23.9255C24.8445 23.6019 24.5821 23.3395 24.2586 23.3395C23.935 23.3395 23.6726 23.6019 23.6726 23.9255V28.2422C23.6726 28.5653 23.4098 28.8281 23.0867 28.8281H1.75857C1.43548 28.8281 1.17263 28.5653 1.17263 28.2422V1.75781C1.17263 1.43473 1.43548 1.17188 1.75857 1.17188H23.0867C23.4098 1.17188 23.6726 1.43473 23.6726 1.75781V8.12988C23.6726 8.4535 23.935 8.71582 24.2586 8.71582Z"
                    fill="#34A853"
                  />
                  <path
                    d="M12.4223 3.16406C9.44988 3.16406 7.03166 5.58229 7.03166 8.55469C7.03166 10.0967 7.68264 11.4894 8.72397 12.4728C8.74348 12.4937 8.76422 12.5134 8.7869 12.5314C9.74613 13.4091 11.0227 13.9453 12.4222 13.9453C13.8217 13.9453 15.0983 13.409 16.0576 12.5314C16.0802 12.5134 16.101 12.4936 16.1205 12.4728C17.1619 11.4894 17.8129 10.0967 17.8129 8.55469C17.8129 5.58229 15.3947 3.16406 12.4223 3.16406ZM12.4223 12.7734C11.4655 12.7734 10.5825 12.4528 9.87399 11.914C10.389 11.0008 11.35 10.4297 12.4223 10.4297C13.4946 10.4297 14.4556 11.0008 14.9706 11.914C14.262 12.4528 13.3791 12.7734 12.4223 12.7734ZM11.4848 8.32031V7.93945C11.4848 7.42254 11.9054 7.00195 12.4223 7.00195C12.9392 7.00195 13.3598 7.42254 13.3598 7.93945V8.32031C13.3598 8.83723 12.9392 9.25781 12.4223 9.25781C11.9054 9.25781 11.4848 8.83723 11.4848 8.32031ZM15.8172 11.0556C15.3851 10.4147 14.7862 9.91629 14.0909 9.60855C14.3668 9.25189 14.5317 8.80512 14.5317 8.32031V7.93945C14.5317 6.77631 13.5854 5.83008 12.4223 5.83008C11.2591 5.83008 10.3129 6.77631 10.3129 7.93945V8.32031C10.3129 8.80512 10.4777 9.25189 10.7537 9.60855C10.0584 9.91629 9.45949 10.4147 9.02736 11.0556C8.51004 10.3553 8.20354 9.49025 8.20354 8.55469C8.20354 6.22846 10.0961 4.33594 12.4223 4.33594C14.7485 4.33594 16.641 6.22846 16.641 8.55469C16.641 9.49025 16.3345 10.3553 15.8172 11.0556Z"
                    fill="#34A853"
                  />
                  <path
                    d="M15.5863 25.6641H12.4223C12.0987 25.6641 11.8363 25.9264 11.8363 26.25C11.8363 26.5736 12.0987 26.8359 12.4223 26.8359H15.5863C15.9099 26.8359 16.1723 26.5736 16.1723 26.25C16.1723 25.9264 15.9099 25.6641 15.5863 25.6641Z"
                    fill="#34A853"
                  />
                  <path
                    d="M15.5863 21H7.26599C6.94244 21 6.68005 21.2623 6.68005 21.5859C6.68005 21.9096 6.94244 22.1719 7.26599 22.1719H15.5863C15.9099 22.1719 16.1722 21.9096 16.1722 21.5859C16.1722 21.2623 15.9099 21 15.5863 21Z"
                    fill="#34A853"
                  />
                  <path
                    d="M5.17772 17.492C5.0688 17.383 4.91763 17.3203 4.76294 17.3203C4.60878 17.3203 4.45761 17.383 4.34868 17.492C4.2397 17.601 4.177 17.7521 4.177 17.9062C4.177 18.0604 4.23964 18.2115 4.34868 18.3205C4.45825 18.4295 4.60878 18.4922 4.76294 18.4922C4.91763 18.4922 5.06821 18.4295 5.17772 18.3205C5.28671 18.2115 5.34946 18.0604 5.34946 17.9062C5.34946 17.7521 5.28677 17.601 5.17772 17.492Z"
                    fill="#34A853"
                  />
                  <path
                    d="M5.17772 21.1717C5.06821 21.0627 4.91763 21 4.76294 21C4.60878 21 4.45825 21.0627 4.34868 21.1717C4.2397 21.2807 4.177 21.4318 4.177 21.5859C4.177 21.74 4.23964 21.8912 4.34868 22.0002C4.45761 22.1092 4.60878 22.1719 4.76294 22.1719C4.91763 22.1719 5.0688 22.1092 5.17772 22.0002C5.28671 21.8912 5.34946 21.74 5.34946 21.5859C5.34946 21.4318 5.28677 21.2807 5.17772 21.1717Z"
                    fill="#34A853"
                  />
                  <path
                    d="M15.5863 17.3203H7.26599C6.94244 17.3203 6.68005 17.5826 6.68005 17.9062C6.68005 18.2299 6.94244 18.4922 7.26599 18.4922H15.5863C15.9099 18.4922 16.1722 18.2299 16.1722 17.9062C16.1722 17.5826 15.9099 17.3203 15.5863 17.3203Z"
                    fill="#34A853"
                  />
                  <path
                    d="M28.7697 7.63544C28.2004 7.30679 27.5372 7.21948 26.9022 7.38958C26.2673 7.55974 25.7365 7.96696 25.408 8.5362L18.0344 21.3075C17.994 21.3775 17.9685 21.4551 17.9595 21.5355L17.4405 26.1845C17.4147 26.4159 17.5283 26.6406 17.7298 26.757C17.8208 26.8095 17.9219 26.8355 18.0227 26.8355C18.1453 26.8355 18.2674 26.7971 18.3703 26.7214L22.1369 23.9473C22.202 23.8994 22.2565 23.8385 22.2969 23.7685L29.6704 10.9972C30.3489 9.82204 29.9448 8.31395 28.7697 7.63544ZM18.7537 24.9835L19.0247 22.5559L20.7206 23.535L18.7537 24.9835ZM21.575 22.6751L19.3423 21.386L25.2594 11.1374L27.4921 12.4264L21.575 22.6751ZM28.6555 10.4112L28.078 11.4116L25.8452 10.1225L26.4228 9.12214C26.5949 8.82395 26.8729 8.61067 27.2055 8.52155C27.5382 8.43237 27.8855 8.47819 28.1837 8.65034C28.4818 8.82249 28.6951 9.10046 28.7842 9.43304C28.8734 9.76561 28.8277 10.113 28.6555 10.4112Z"
                    fill="#34A853"
                  />
                </g>
                <defs>
                  <clipPath id="application">
                    <rect width={30} height={30} fill="white" />
                  </clipPath>
                </defs>
              </svg>
            </div>
            <div className="content">
              <h5 className="lh-sm">{applicationList.length}</h5>
              <p className="font-20">Application</p>
            </div>
          </div>
          <div className="single__overview">
            <div className="icon">
              <svg
                width={38}
                height={28}
                viewBox="0 0 38 28"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
              >
                <path
                  d="M37.1276 13.5672C35.7005 9.69514 33.223 6.34657 30.0013 3.93536C26.7796 1.52415 22.9549 0.156001 19 0C15.0451 0.156001 11.2204 1.52415 7.99871 3.93536C4.77701 6.34657 2.2995 9.69514 0.872395 13.5672C0.776015 13.8468 0.776015 14.153 0.872395 14.4327C2.2995 18.3047 4.77701 21.6533 7.99871 24.0645C11.2204 26.4757 15.0451 27.8438 19 27.9998C22.9549 27.8438 26.7796 26.4757 30.0013 24.0645C33.223 21.6533 35.7005 18.3047 37.1276 14.4327C37.224 14.153 37.224 13.8468 37.1276 13.5672ZM19 25.4544C12.5692 25.4544 5.77437 20.4526 3.31125 13.9999C5.77437 7.54723 12.5692 2.54544 19 2.54544C25.4308 2.54544 32.2256 7.54723 34.6888 13.9999C32.2256 20.4526 25.4308 25.4544 19 25.4544Z"
                  fill="#34A853"
                />
                <path
                  d="M19 7C17.6156 7 16.2622 7.41054 15.1111 8.17971C13.9599 8.94887 13.0627 10.0421 12.5329 11.3212C12.0031 12.6003 11.8645 14.0077 12.1346 15.3656C12.4047 16.7234 13.0713 17.9707 14.0503 18.9497C15.0293 19.9286 16.2765 20.5953 17.6344 20.8654C18.9923 21.1355 20.3997 20.9969 21.6788 20.4671C22.9579 19.9373 24.0511 19.0401 24.8203 17.8889C25.5894 16.7378 26 15.3844 26 14C26 12.1435 25.2625 10.363 23.9497 9.05024C22.637 7.73749 20.8565 7 19 7ZM19 18.6666C18.0771 18.6666 17.1748 18.3929 16.4074 17.8801C15.64 17.3674 15.0418 16.6385 14.6886 15.7858C14.3354 14.9331 14.243 13.9948 14.4231 13.0895C14.6031 12.1843 15.0476 11.3528 15.7002 10.7001C16.3529 10.0475 17.1844 9.60305 18.0896 9.42299C18.9948 9.24292 19.9332 9.33534 20.7859 9.68855C21.6386 10.0418 22.3674 10.6399 22.8802 11.4073C23.393 12.1747 23.6667 13.077 23.6667 14C23.6667 15.2376 23.175 16.4246 22.2998 17.2998C21.4247 18.1749 20.2377 18.6666 19 18.6666Z"
                  fill="#34A853"
                />
              </svg>
            </div>
            <div className="content">
              <h5 className="lh-sm">{applicationAppliedList.length}</h5>
              <p className="font-20">Application Accepted</p>
            </div>
          </div>
          <div className="single__overview">
            <div className="icon">
              <svg
                width={30}
                height={29}
                viewBox="0 0 30 29"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
              >
                <path
                  d="M10.8617 18.1248L15 15.5673L19.1383 18.1248L18.0383 13.3274L21.6983 10.128L16.8883 9.69327L15 5.19307L13.1117 9.69327L8.30167 10.128L11.9617 13.3274L10.8617 18.1248ZM0 29V2.74428C0 1.96198 0.257222 1.30931 0.771667 0.786262C1.28611 0.26322 1.92611 0.00113213 2.69167 0H27.3083C28.075 0 28.715 0.262087 29.2283 0.786262C29.7417 1.31044 29.9989 1.96311 30 2.74428V21.0321C30 21.8133 29.7428 22.4659 29.2283 22.9901C28.7139 23.5143 28.0739 23.7758 27.3083 23.7747H5.12833L0 29ZM4.41667 22.0765H27.3083C27.5639 22.0765 27.7989 21.9678 28.0133 21.7504C28.2278 21.5331 28.3344 21.2936 28.3333 21.0321V2.74258C28.3333 2.48219 28.2267 2.24274 28.0133 2.02424C27.8 1.80574 27.565 1.69706 27.3083 1.69819H2.69167C2.43611 1.69819 2.20111 1.80687 1.98667 2.02424C1.77222 2.24161 1.66556 2.48106 1.66667 2.74258V24.87L4.41667 22.0765Z"
                  fill="#34A853"
                />
              </svg>
            </div>
            <div className="content">
              <h5 className="lh-sm">{applicationRemoveList.length}</h5>
              <p className="font-20">Application Rejected</p>
            </div>
          </div>
        </div>
      </div>
      
      {/* Applied Jobs */}
      <div className="applied__jobs">
        <h6 className="fw-medium mb-30">Recent Applicants</h6>
        <div className="short__list__candidate">
          {/* single item */}
          
          {/* single item end */}
          {applicationAppliedList.map((list) => (
                      <div key={list.id} className="single__shortlist__item">
                        <div className="author__info">
                          <div className="author__meta">
                            <div className="author__image">
                              <img
                                src={list.user.profile.profile_picture_path}
                                alt=""
                              />
                            </div>
                            <div className="author__name">
                              <h6 className="fw-semibold mb-1">
                                {list.user.name}
                              </h6>
                              <p className="mb-0">{list.user.profile.title}</p>
                            </div>
                          </div>
                          <div className="author__info__list">
                            <span>
                              <i className="fa-light fa-location-dot" />{" "}
                              {list.user.profile.address}
                            </span>
                            <span>
                              <i className="fa-light fa-clock" />{" "}
                              {formatDate(list.created_at)}
                              <button className="action__click">Approved</button>
                            </span>
                          </div>
                        </div>
                        <div className="shortlist__action">
                        <button
                            onClick={() => handleDownload(list.resume_path)}
                            className="action__item__long"
                          >
                            <svg
                              width={18}
                              height={18}
                              viewBox="0 0 18 18"
                              fill="none"
                              xmlns="http://www.w3.org/2000/svg"
                            >
                              <g clipPath="url(#clip0_441_6)">
                                <path
                                  d="M14.5547 5.22949C14.7488 5.22949 14.9062 5.0721 14.9062 4.87793V1.05469C14.9062 0.473133 14.4331 0 13.8516 0H1.05469C0.473133 0 0 0.473133 0 1.05469V16.9453C0 17.5269 0.473133 18 1.05469 18H13.8516C14.4331 18 14.9062 17.5269 14.9062 16.9453V14.3553C14.9062 14.1611 14.7488 14.0037 14.5547 14.0037C14.3606 14.0037 14.2031 14.1611 14.2031 14.3553V16.9453C14.2031 17.1392 14.0454 17.2969 13.8516 17.2969H1.05469C0.860836 17.2969 0.703125 17.1392 0.703125 16.9453V1.05469C0.703125 0.860836 0.860836 0.703125 1.05469 0.703125H13.8516C14.0454 0.703125 14.2031 0.860836 14.2031 1.05469V4.87793C14.2031 5.0721 14.3606 5.22949 14.5547 5.22949Z"
                                  fill="#939393"
                                />
                                <path
                                  d="M7.45312 1.89844C5.66968 1.89844 4.21875 3.34937 4.21875 5.13281C4.21875 6.05802 4.60934 6.89361 5.23413 7.48368C5.24584 7.49619 5.25828 7.50804 5.27189 7.51883C5.84743 8.04544 6.61338 8.36715 7.45309 8.36715C8.2928 8.36715 9.05875 8.0454 9.63429 7.51883C9.64789 7.50804 9.66034 7.49616 9.67205 7.48368C10.2969 6.89361 10.6875 6.05802 10.6875 5.13281C10.6875 3.34937 9.23657 1.89844 7.45312 1.89844ZM7.45312 7.66406C6.87906 7.66406 6.34925 7.47169 5.92414 7.14839C6.23313 6.60048 6.80973 6.25781 7.45312 6.25781C8.09652 6.25781 8.67312 6.60048 8.98211 7.14839C8.55696 7.47169 8.02719 7.66406 7.45312 7.66406ZM6.89062 4.99219V4.76367C6.89062 4.45352 7.14298 4.20117 7.45312 4.20117C7.76327 4.20117 8.01562 4.45352 8.01562 4.76367V4.99219C8.01562 5.30234 7.76327 5.55469 7.45312 5.55469C7.14298 5.55469 6.89062 5.30234 6.89062 4.99219ZM9.49008 6.63339C9.2308 6.24885 8.87147 5.94977 8.45427 5.76513C8.61985 5.55114 8.71875 5.28307 8.71875 4.99219V4.76367C8.71875 4.06578 8.15101 3.49805 7.45312 3.49805C6.75524 3.49805 6.1875 4.06578 6.1875 4.76367V4.99219C6.1875 5.28307 6.28639 5.55114 6.45198 5.76513C6.03478 5.94977 5.67545 6.24885 5.41617 6.63339C5.10578 6.21316 4.92188 5.69415 4.92188 5.13281C4.92188 3.73707 6.05739 2.60156 7.45312 2.60156C8.84886 2.60156 9.98437 3.73707 9.98437 5.13281C9.98437 5.69415 9.80047 6.21316 9.49008 6.63339Z"
                                  fill="#939393"
                                />
                                <path
                                  d="M9.35156 15.3984H7.45312C7.25899 15.3984 7.10156 15.5558 7.10156 15.75C7.10156 15.9442 7.25899 16.1016 7.45312 16.1016H9.35156C9.54569 16.1016 9.70312 15.9442 9.70312 15.75C9.70312 15.5558 9.54569 15.3984 9.35156 15.3984Z"
                                  fill="#939393"
                                />
                                <path
                                  d="M9.35156 13.4297H4.35938C4.16524 13.4297 4.00781 13.5871 4.00781 13.7812C4.00781 13.9754 4.16524 14.1328 4.35938 14.1328H9.35156C9.54569 14.1328 9.70312 13.9754 9.70312 13.7812C9.70312 13.5871 9.54569 13.4297 9.35156 13.4297Z"
                                  fill="#939393"
                                />
                                <path
                                  d="M9.35156 11.4609H4.35938C4.16524 11.4609 4.00781 11.6183 4.00781 11.8125C4.00781 12.0067 4.16524 12.1641 4.35938 12.1641H9.35156C9.54569 12.1641 9.70312 12.0067 9.70312 11.8125C9.70312 11.6183 9.54569 11.4609 9.35156 11.4609Z"
                                  fill="#939393"
                                />
                                <path
                                  d="M3.10629 9.5952C3.04094 9.5298 2.95023 9.49219 2.85742 9.49219C2.76493 9.49219 2.67422 9.5298 2.60887 9.5952C2.54348 9.66059 2.50586 9.75129 2.50586 9.84375C2.50586 9.93621 2.54344 10.0269 2.60887 10.0923C2.67461 10.1577 2.76493 10.1953 2.85742 10.1953C2.95023 10.1953 3.04059 10.1577 3.10629 10.0923C3.17168 10.0269 3.20934 9.93621 3.20934 9.84375C3.20934 9.75129 3.17172 9.66059 3.10629 9.5952Z"
                                  fill="#939393"
                                />
                                <path
                                  d="M3.10629 11.5639C3.04059 11.4986 2.95023 11.4609 2.85742 11.4609C2.76493 11.4609 2.67461 11.4986 2.60887 11.5639C2.54348 11.6293 2.50586 11.72 2.50586 11.8125C2.50586 11.905 2.54344 11.9957 2.60887 12.0611C2.67461 12.1264 2.76493 12.1641 2.85742 12.1641C2.95023 12.1641 3.04059 12.1264 3.10629 12.0611C3.17168 11.9957 3.20934 11.905 3.20934 11.8125C3.20934 11.72 3.17172 11.6293 3.10629 11.5639Z"
                                  fill="#939393"
                                />
                                <path
                                  d="M3.10629 13.5327C3.04059 13.4673 2.95023 13.4297 2.85742 13.4297C2.76493 13.4297 2.67461 13.4673 2.60887 13.5327C2.54348 13.5981 2.50586 13.6888 2.50586 13.7812C2.50586 13.8737 2.54344 13.9644 2.60887 14.0298C2.67422 14.0952 2.76493 14.1328 2.85742 14.1328C2.95023 14.1328 3.04094 14.0952 3.10629 14.0298C3.17168 13.9644 3.20934 13.8737 3.20934 13.7812C3.20934 13.6888 3.17172 13.5981 3.10629 13.5327Z"
                                  fill="#939393"
                                />
                                <path
                                  d="M9.35156 9.49219H4.35938C4.16524 9.49219 4.00781 9.64958 4.00781 9.84375C4.00781 10.0379 4.16524 10.1953 4.35938 10.1953H9.35156C9.54569 10.1953 9.70312 10.0379 9.70312 9.84375C9.70312 9.64958 9.54569 9.49219 9.35156 9.49219Z"
                                  fill="#939393"
                                />
                                <path
                                  d="M17.2616 4.58126C16.92 4.38407 16.5221 4.33169 16.1411 4.43375C15.7602 4.53584 15.4417 4.78018 15.2446 5.12172L10.8204 12.7845C10.7962 12.8265 10.7809 12.8731 10.7755 12.9213L10.4641 15.7107C10.4486 15.8495 10.5167 15.9843 10.6377 16.0542C10.6923 16.0857 10.7529 16.1013 10.8134 16.1013C10.887 16.1013 10.9602 16.0783 11.0219 16.0328L13.2819 14.3684C13.321 14.3396 13.3537 14.3031 13.3779 14.2611L17.802 6.59832C18.2091 5.89322 17.9667 4.98837 17.2616 4.58126ZM11.252 14.9901L11.4146 13.5335L12.4321 14.121L11.252 14.9901ZM12.9448 13.605L11.6052 12.8316L15.1554 6.68241L16.495 7.45585L12.9448 13.605ZM17.1931 6.24672L16.8466 6.84694L15.5069 6.07351L15.8535 5.47328C15.9568 5.29437 16.1235 5.1664 16.3231 5.11293C16.5227 5.05942 16.7311 5.08692 16.91 5.1902C17.0889 5.29349 17.2169 5.46027 17.2703 5.65982C17.3238 5.85937 17.2964 6.06781 17.1931 6.24672Z"
                                  fill="#939393"
                                />
                              </g>
                              <defs>
                                <clipPath id="clip0_441_6">
                                  <rect width={18} height={18} fill="white" />
                                </clipPath>
                              </defs>
                            </svg>
                            Download Cv
                          </button>
                          <button
                            onClick={() => handleShow(list.id)}
                            className="action__item"
                          >
                            {/* <span className="notification__item">10</span> */}
                            <svg
                              width={22}
                              height={16}
                              viewBox="0 0 22 16"
                              fill="none"
                              xmlns="http://www.w3.org/2000/svg"
                            >
                              <path
                                d="M20.544 7.045C20.848 7.471 21 7.685 21 8C21 8.316 20.848 8.529 20.544 8.955C19.178 10.871 15.689 15 11 15C6.31 15 2.822 10.87 1.456 8.955C1.152 8.529 1 8.315 1 8C1 7.684 1.152 7.471 1.456 7.045C2.822 5.129 6.311 1 11 1C15.69 1 19.178 5.13 20.544 7.045Z"
                                stroke="#0B0D28"
                                strokeWidth="1.5"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                              />
                              <path
                                d="M14 8C14 7.20435 13.6839 6.44129 13.1213 5.87868C12.5587 5.31607 11.7956 5 11 5C10.2044 5 9.44129 5.31607 8.87868 5.87868C8.31607 6.44129 8 7.20435 8 8C8 8.79565 8.31607 9.55871 8.87868 10.1213C9.44129 10.6839 10.2044 11 11 11C11.7956 11 12.5587 10.6839 13.1213 10.1213C13.6839 9.55871 14 8.79565 14 8Z"
                                stroke="#0B0D28"
                                strokeWidth="1.5"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                              />
                            </svg>
                          </button>
                          
                        </div>
                      </div>
                    ))}
        
        </div>
      </div>
      {/* Applied Jobs end */}
    </div>
   
  </div>
  </div>
  </div>

  {/* xxx */}
  <Footer/>
  <Myscript/>
</>
  );
}
